==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/logistics/LogisticsReceiveJDLogisticsReqBean.java <==
package global.hh.openapi.sdk.api.bean.logistics;

        import java.util.List;

/**
 * @description: 提供给京东、荣庆等 物流信息推送
 * @author: 777771
 * @date: 2021-42-24 13:42:56
 */
public class LogisticsReceiveJDLogisticsReqBean {
    /**
     * JD实际发货时间
     */
    private String deliverDate;

    /**
     * 管易发货单号
     */
    private String gyNo;

    /**
     * 平台单号
     */
    private String orderNo;

    /**
     * 产品信息
     */
    private List<LogisticsReceiveJDLogisticsProductInfoItem> productInfo;

    /**
     * 推送时间
     */
    private String pushDate;

    /**
     * 运单号
     */
    private String wayBillNo;

    /**
     * wms子单号
     */
    private String wmsChildNo;

    public LogisticsReceiveJDLogisticsReqBean(){
    }

    public LogisticsReceiveJDLogisticsReqBean(String deliverDate,String gyNo,String orderNo,List<LogisticsReceiveJDLogisticsProductInfoItem> productInfo,String pushDate,String wayBillNo,String wmsChildNo){
        this.deliverDate=deliverDate;
        this.gyNo=gyNo;
        this.orderNo=orderNo;
        this.productInfo=productInfo;
        this.pushDate=pushDate;
        this.wayBillNo=wayBillNo;
        this.wmsChildNo=wmsChildNo;
    }

    private String getDeliverDate() {
        return deliverDate;
    }

    private void setDeliverDate(String deliverDate) {
        this.deliverDate = deliverDate;
    }
    private String getGyNo() {
        return gyNo;
    }

    private void setGyNo(String gyNo) {
        this.gyNo = gyNo;
    }
    private String getOrderNo() {
        return orderNo;
    }

    private void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }
    private List<LogisticsReceiveJDLogisticsProductInfoItem> getProductInfo() {
        return productInfo;
    }

    private void setProductInfo(List<LogisticsReceiveJDLogisticsProductInfoItem> productInfo) {
        this.productInfo = productInfo;
    }
    private String getPushDate() {
        return pushDate;
    }

    private void setPushDate(String pushDate) {
        this.pushDate = pushDate;
    }
    private String getWayBillNo() {
        return wayBillNo;
    }

    private void setWayBillNo(String wayBillNo) {
        this.wayBillNo = wayBillNo;
    }
    private String getWmsChildNo() {
        return wmsChildNo;
    }

    private void setWmsChildNo(String wmsChildNo) {
        this.wmsChildNo = wmsChildNo;
    }
}

==> biostime-openapi-sdk-1.5.9.2-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/logistics/LogisticsReceiveJDLogisticsReqBean.java <==
package global.hh.openapi.sdk.api.bean.logistics;

        import java.util.List;

/**
 * @description: 接收 京东、荣庆等第三方推送的物流信息 服务
 * @author: 23055
 * @date: 2021-17-24 14:17:29
 */
public class LogisticsReceiveJDLogisticsReqBean {
    /**
     * JD实际发货时间
     */
    private String deliverDate;

    /**
     * 管易发货单号
     */
    private String gyNo;

    /**
     * 平台单号
     */
    private String orderNo;

    /**
     * 产品信息
     */
    private List<LogisticsReceiveJDLogisticsProductInfoItem> productInfo;

    /**
     * 推送时间
     */
    private String pushDate;

    /**
     * 运单号
     */
    private String wayBillNo;

    /**
     * wms子单号
     */
    private String wmsChildNo;

    public LogisticsReceiveJDLogisticsReqBean(){
    }

    public LogisticsReceiveJDLogisticsReqBean(String deliverDate,String gyNo,String orderNo,List<LogisticsReceiveJDLogisticsProductInfoItem> productInfo,String pushDate,String wayBillNo,String wmsChildNo){
        this.deliverDate=deliverDate;
        this.gyNo=gyNo;
        this.orderNo=orderNo;
        this.productInfo=productInfo;
        this.pushDate=pushDate;
        this.wayBillNo=wayBillNo;
        this.wmsChildNo=wmsChildNo;
    }

    public String getDeliverDate() {
        return deliverDate;
    }

    public void setDeliverDate(String deliverDate) {
        this.deliverDate = deliverDate;
    }
    public String getGyNo() {
        return gyNo;
    }

    public void setGyNo(String gyNo) {
        this.gyNo = gyNo;
    }
    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }
    public List<LogisticsReceiveJDLogisticsProductInfoItem> getProductInfo() {
        return productInfo;
    }

    public void setProductInfo(List<LogisticsReceiveJDLogisticsProductInfoItem> productInfo) {
        this.productInfo = productInfo;
    }
    public String getPushDate() {
        return pushDate;
    }

    public void setPushDate(String pushDate) {
        this.pushDate = pushDate;
    }
    public String getWayBillNo() {
        return wayBillNo;
    }

    public void setWayBillNo(String wayBillNo) {
        this.wayBillNo = wayBillNo;
    }
    public String getWmsChildNo() {
        return wmsChildNo;
    }

    public void setWmsChildNo(String wmsChildNo) {
        this.wmsChildNo = wmsChildNo;
    }
}
